package routers

import (
	"spaceofcheng/services/controllers"
	"spaceofcheng/services/controllers/customer"
	"spaceofcheng/services/controllers/goods"
	"spaceofcheng/services/controllers/message"
	"spaceofcheng/services/controllers/user"

	"github.com/astaxie/beego"
)

func getWechatRoutes() beego.LinkNamespace {
	prefix := beego.AppConfig.String("api::wechat")

	return beego.NSNamespace(prefix,
		// 商品分类
		beego.NSRouter("/type/goods", &goods.GoodsController{}, "get:GetGoodsType"),
		beego.NSRouter("/type/goods/:typeid", &goods.GoodsController{}, "get:GetGoodsTypeByID"),
		beego.NSRouter("/type/goods", &goods.GoodsController{}, "post:SaveGoodsType"),
		beego.NSRouter("/type/goods/:typeid", &goods.GoodsController{}, "put:SaveGoodsType"),
		beego.NSRouter("/type/goods/:typeid", &goods.GoodsController{}, "delete:DelGoodsType"),

		// 商品规格
		beego.NSRouter("/spec/goods", &goods.GoodsController{}, "get:GetGoodsSpec"),
		beego.NSRouter("/spec/goods/:specid", &goods.GoodsController{}, "get:GetGoodsSpecByID"),
		beego.NSRouter("/spec/goods", &goods.GoodsController{}, "post:SaveGoodsSpec"),
		beego.NSRouter("/spec/goods/:specid", &goods.GoodsController{}, "put:SaveGoodsSpec"),
		beego.NSRouter("/spec/goods/:specid", &goods.GoodsController{}, "delete:DelGoodsSpec"),

		// 系统用户
		beego.NSRouter("/user", &user.UserController{}, "get:GetUserList"),
		beego.NSRouter("/user/:userid", &user.UserController{}, "get:GetUserByID"),
		beego.NSRouter("/user/:userid/password", &user.UserController{}, "put:UpdatePassword"),
		beego.NSRouter("/user/password/reset", &user.UserController{}, "put:ResetPassword"),
		beego.NSRouter("/signout", &user.UserController{}, "post:SignOut"),

		// cms 位置
		beego.NSRouter("/cms/area", &message.MessageController{}, "get:GetLocations"),
		beego.NSRouter("/cms/area/:locationid", &message.MessageController{}, "get:GetLocationById"),
		beego.NSRouter("/cms/area", &message.MessageController{}, "post:SaveLocation"),
		beego.NSRouter("/cms/area/:locationid", &message.MessageController{}, "put:SaveLocation"),
		beego.NSRouter("/cms/area/:locationid", &message.MessageController{}, "delete:DelLocation"),

		// cms
		beego.NSRouter("/cms/info", &message.MessageController{}, "get:GetCmsInfoList"),
		beego.NSRouter("/cms/info/:infoid", &message.MessageController{}, "get:GetCmsInfoByID"),
		beego.NSRouter("/cms/info", &message.MessageController{}, "post:SaveCmsInfo"),
		beego.NSRouter("/cms/info/:infoid", &message.MessageController{}, "put:SaveCmsInfo"),
		beego.NSRouter("/cms/info/:infoid", &message.MessageController{}, "delete:DelCmsInfo"),

		// cms 图片
		beego.NSRouter("/cms/image", &message.MessageController{}, "get:GetImgList"),
		beego.NSRouter("/cms/image/:imgid", &message.MessageController{}, "get:GetImgByID"),
		beego.NSRouter("/cms/image", &message.MessageController{}, "post:SaveImage"),
		beego.NSRouter("/cms/image/:imgid", &message.MessageController{}, "put:SaveImage"),
		beego.NSRouter("/cms/image/:imgid", &message.MessageController{}, "delete:DelImg"),

		// cms 消息
		beego.NSRouter("/cms/news", &message.MessageController{}, "get:GetNews"),
		beego.NSRouter("/cms/news/:newsid", &message.MessageController{}, "get:GetNewsByID"),
		beego.NSRouter("/cms/news", &message.MessageController{}, "post:SaveNews"),
		beego.NSRouter("/cms/news/:newsid", &message.MessageController{}, "put:SaveNews"),
		beego.NSRouter("/cms/news/:newsid", &message.MessageController{}, "delete:DelNews"),

		// cms 案场
		beego.NSRouter("/cms/case", &message.MessageController{}, "get:GetCmsCase"),
		beego.NSRouter("/cms/case/:cmscaseid", &message.MessageController{}, "get:GetCmsCaseByID"),
		beego.NSRouter("/cms/case", &message.MessageController{}, "post:SaveCmsCase"),
		beego.NSRouter("/cms/case/:cmscaseid", &message.MessageController{}, "put:SaveCmsCase"),
		beego.NSRouter("/cms/case/:cmscaseid", &message.MessageController{}, "delete:DelCmsCase"),

		// 文件
		beego.NSRouter("/file", &controllers.BaseController{}, "post:FileUpload"),

		// 会员
		beego.NSRouter("/customer", &customer.CustomerController{}, "get:CustWXList"),
	)
}
