package cases

import (
	"spaceofcheng/services/models/cases"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/service"
	"spaceofcheng/services/utils"
)

// CaseServ 系统处理
type CaseServ struct {
	ctx *utils.Context
	dao *cases.CaseDAO
}

// NewCaseServ 初始化
func NewCaseServ(ctx *utils.Context) *CaseServ {
	return &CaseServ{
		ctx: ctx,
		dao: cases.NewCaseDAO(ctx),
	}
}

// GetCases 获取案场列表
func (s *CaseServ) GetCases(caseids, casename string, page, pageSize int) (map[string]interface{}, error) {
	if pageSize == 0 {
		pageSize = service.PAGENUM
	}
	cases, err := s.dao.GetCaseList(caseids, casename, page, pageSize)
	if err != nil {
		return nil, err
	}
	total, err := s.dao.GetCaseCount(caseids, casename)
	if err != nil {
		return nil, err
	}

	return map[string]interface{}{
		"list":     cases,
		"pagesize": pageSize,
		"pagenum":  total,
		"page":     page,
	}, err
}

// GetCaseByID 根据案场id获取案场
func (s *CaseServ) GetCaseByID(caseid string) (*model.SysCase, error) {
	caseinfo, err := s.dao.GetCaseByID(caseid)
	return caseinfo, err
}

// SaveCase 保存案场
func (s *CaseServ) SaveCase(caseinfo model.SysCase) (*model.SysCase, error) {
	var newInfo *model.SysCase
	var err error
	if caseinfo.CaseId == "" {
		newInfo, err = s.dao.AddCase(caseinfo)
	} else {
		err = s.dao.UpdateCase(caseinfo)
		newInfo = &caseinfo
	}
	return newInfo, err
}

// DelCase 删除案场
func (s *CaseServ) DelCase(caseid string) error {
	err := s.dao.DelCase(caseid)
	return err
}
