package cases

import (
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/service"
	"spaceofcheng/services/utils"
	"strconv"
)

// GetKeysByCase 根据案场获取钥匙信息
func (s *CaseServ) GetKeysByCase(caseid, num string, page, pageSize int) (map[string]interface{}, error) {
	cases := s.ctx.Get("cases").([]model.SysUserCase)
	isdict := false
	for _, value := range cases {
		if caseid == value.CaseId {
			isdict = true
		}
	}
	if !isdict {
		return nil, utils.LogError("您没有该案场的权限！")
	}

	if pageSize == 0 {
		pageSize = service.PAGENUM
	}
	keys, err := s.dao.GetKeysByCase(caseid, num, page, pageSize)
	if err != nil {
		return nil, err
	}
	total, err := s.dao.GetCaseCount(caseid, num)
	if err != nil {
		return nil, err
	}

	for index, key := range keys {
		use, err := s.dao.GetCurrentKey(key.KeyId)
		if err != nil {
			return nil, err
		}
		keys[index].CustomerId = use.CustomerId
		keys[index].CustomerName = use.CustomerName
	}

	return map[string]interface{}{
		"list":     keys,
		"pagesize": pageSize,
		"pagenum":  total,
		"page":     page,
	}, err
}

// AddKeys 保存钥匙
func (s *CaseServ) AddKeys(orgid, caseid string, beginnum, endnum int) error {
	if endnum <= beginnum {
		return utils.LogError("锁柜编号起始不能大于截止时间！")
	}

	for i := beginnum; i <= endnum; i++ {
		key := model.TaCaseKey{
			OrgId:   orgid,
			CaseId:  caseid,
			LockNum: strconv.Itoa(i),
		}
		_, err := s.dao.AddKey(key)
		if err != nil {
			return err
		}
	}
	return nil
}

// UnLockKey 解锁
func (s *CaseServ) UnLockKey(keyid string) error {
	err := s.dao.UnLockKey(keyid)
	return err
}

// DelKey 刪除
func (s *CaseServ) DelKey(keyid string) error {
	use, err := s.dao.GetCurrentKey(keyid)
	if err != nil {
		return err
	}

	if use != nil {
		return utils.LogError("当前锁柜未解锁！请先解锁再删除！")
	}

	err = s.dao.DelKey(keyid)
	return err
}
