package cases

import (
	"spaceofcheng/services/models/cases"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/service"
)

// GetTagList 获取tag列表
func (s *CaseServ) GetTagList(caseids string, page, pageSize int) (map[string]interface{}, error) {
	if pageSize == 0 {
		pageSize = service.PAGENUM
	}
	tags, err := s.dao.GetTagList(caseids, page, pageSize)
	if err != nil {
		return nil, err
	}
	total, err := s.dao.GetTagCount(caseids)
	if err != nil {
		return nil, err
	}

	return map[string]interface{}{
		"list":     tags,
		"pagesize": pageSize,
		"pagenum":  total,
		"page":     page,
	}, err
}

// GetTagByID 根据ID获取标签
func (s *CaseServ) GetTagByID(tagid string) (*cases.Tag, error) {
	tag, err := s.dao.GetTagByID(tagid)
	if err != nil {
		return nil, err
	}
	if tag != nil {
		tagcases, err := s.dao.GetTagCaseByTagID(tagid)
		if err != nil {
			return nil, err
		}
		tag.TagCases = tagcases
	}
	return tag, err
}

// SaveTag 保存标签
func (s *CaseServ) SaveTag(tag model.SysTag, caseids string) (*model.SysTag, error) {
	var newInfo *model.SysTag
	var err error
	if tag.TagId == "" {
		newInfo, err = s.dao.AddTag(tag)
	} else {
		err = s.dao.UpdateTag(tag)
		newInfo = &tag
	}
	if err != nil {
		return nil, err
	}
	err = s.dao.DelTagCase(newInfo.TagId)
	if err != nil {
		return nil, err
	}
	err = s.dao.SaveTagCase(newInfo.TagId, caseids)
	if err != nil {
		return nil, err
	}
	return newInfo, err
}

// DelTag 删除标签
func (s *CaseServ) DelTag(tagid string) error {
	err := s.dao.DeleteTag(tagid)
	return err
}
