package message

import (
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/service"
)

// GetImgList 获取图片列表
func (s *MessageServ) GetImgList(orgid string, page int, pageSize int) (map[string]interface{}, error) {
	if pageSize == 0 {
		pageSize = service.PAGENUM
	}
	infos, err := s.dao.GetImgList(orgid, page, pageSize)
	if err != nil {
		return nil, err
	}
	total, err := s.dao.GetImgListCount(orgid)
	if err != nil {
		return nil, err
	}

	return map[string]interface{}{
		"list":     infos,
		"pagesize": pageSize,
		"pagenum":  total,
		"page":     page,
	}, err
}

// GetImgByLocation 根据位置获取图片
func (s *MessageServ) GetImgByLocation(locationid, orgid string) ([]model.TaCmsImages, error) {
	imgs, err := s.dao.GetImgByLocation(locationid, orgid)
	return imgs, err
}

// GetImgByID 获取单条图片信息
func (s *MessageServ) GetImgByID(imgid string) (*model.TaCmsImages, error) {
	img, err := s.dao.GetImgByID(imgid)
	return img, err
}

// SaveImg 保存轮播图信息
func (s *MessageServ) SaveImg(imginfo model.TaCmsImages) (*model.TaCmsImages, error) {
	if imginfo.ImageId == "" {
		newinfo, err := s.dao.AddCmsImg(imginfo)
		return newinfo, err
	}
	err := s.dao.UpdateCmsImg(imginfo)
	return &imginfo, err
}

// DelImg 删除轮播图
func (s *MessageServ) DelImg(imgid string) error {
	err := s.dao.DelCmsImg(imgid)
	return err
}
