package message

import (
	"spaceofcheng/services/models/message"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/service"
)

// GetNewsList 获取咨询列表
func (s *MessageServ) GetNewsList(locationid, orgid string, page int, pageSize int) (map[string]interface{}, error) {
	if pageSize == 0 {
		pageSize = service.PAGENUM
	}
	infos, err := s.dao.GetNewsList(locationid, orgid, page, pageSize)
	if err != nil {
		return nil, err
	}
	total, err := s.dao.GetNewsListCount(locationid, orgid)
	if err != nil {
		return nil, err
	}

	return map[string]interface{}{
		"list":     infos,
		"pagesize": pageSize,
		"pagenum":  total,
		"page":     page,
	}, err
}

// GetNewsByLocation 根据位置id获取咨询信息
func (s *MessageServ) GetNewsByLocation(locationid, orgid string) ([]model.TaCmsNews, error) {
	news, err := s.dao.GetNewsByLocation(locationid, orgid)
	return news, err
}

// GetNewsByID 获取咨询详情
func (s *MessageServ) GetNewsByID(newsid string) (*message.CmsNews, error) {
	info, err := s.dao.GetNewsByID(newsid)
	if err != nil {
		return nil, err
	}
	newslocation, err := s.dao.GetNewsLocationByID(newsid)
	if err != nil {
		return nil, err
	}
	info.NewsLocations = newslocation
	return info, nil
}

// SaveNews 保存咨询信息
func (s *MessageServ) SaveNews(news model.TaCmsNews, locationids string) (*model.TaCmsNews, error) {
	var newInfo *model.TaCmsNews
	var err error
	if news.NewsId == "" {
		newInfo, err = s.dao.AddNews(news)
	} else {
		err = s.dao.UpdateNews(news)
		newInfo = &news
	}
	if err != nil {
		return nil, err
	}
	err = s.dao.DelNewsLocation(newInfo.NewsId)
	if err != nil {
		return nil, err
	}
	err = s.dao.SaveNewsLocation(newInfo.NewsId, locationids)
	if err != nil {
		return nil, err
	}
	return newInfo, err
}

// DelNews 刪除咨询信息
func (s *MessageServ) DelNews(newsid string) error {
	err := s.dao.DelNews(newsid)
	return err
}
